@@ -15,14 +15,17 @@ use XML::LibXML;
 
 use Publican::Localise;
 
-use vars qw(@ISA $VERSION @EXPORT @EXPORT_OK $SINGLETON $LOCALISE);
+use vars qw(@ISA $VERSION @EXPORT @EXPORT_OK $SINGLETON $LOCALISE $SPEC_VERSION);
 
-$VERSION = '2.3';
+$VERSION = '2.5';
 @ISA     = qw(Exporter AutoLoader);
 
 @EXPORT
     = qw(dir_list debug_msg get_all_langs logger help_config maketext old2new new_tree);
 
+# Track when the SPEC file generation is incompatible.
+$SPEC_VERSION = '2.5';
+
 my $DEFAULT_CONFIG_FILE = 'publican.cfg';
 my $DEBUG               = undef;
 my $NOCOLOURS           = undef;
@@ -173,7 +176,11 @@ my %PARAMS = (
 
     },
     dt_obsoletes => {
-        descr => maketext('List of desktop packages this package obsoletes.'),
+        descr => maketext('Space seperated list of packages the desktop package obsoletes.'),
+
+    },
+    dt_requires => {
+        descr => maketext('Space seperated list of packages the desktop package requires.'),
 
     },
     'ec_id' => {
@@ -220,10 +227,12 @@ my %PARAMS = (
         default => '444',
 
     },
+    menu_category => {
+        descr   => maketext('Semi colon seperated list of menu categories for thedesktop package.'),
+    },
     os_ver => {
         descr   => maketext('The OS for which to build packages.'),
         default => '.el5',
-
     },
     product => {
         descr => maketext(
@@ -302,6 +311,10 @@ my %PARAMS = (
         descr   => maketext('The brew dist to use for building the web rpm.'),
         default => 'docs-5E',
     },
+    web_formats => {
+        descr   => maketext('A comma seperated loist of the formats to use for the web packages.'),
+        default => 'html,pdf,html-single,epub',
+    },
     web_home => {
         descr => maketext(
             'This is a home page for a Publican-generated website, not a standard book.'
