@@ -191,6 +191,9 @@ sub build {
                         my $web_type = $self->{publican}->param('web_type');
                         if ( $web_type =~ m/^home$/i ) {
                             $path = "publish/home/$lang";
+                            fcopy( 'site_overrides.css',
+                                'publish/home/site_overrides.css' )
+                                if ( -f 'site_overrides.css' );
                         }
                         elsif ( $web_type =~ m/^product$/i ) {
                             $path = "publish/home/$lang/$product";
@@ -215,8 +218,17 @@ sub build {
                             "$path/." );
                     }
                     else {
-                        rcopy( "$tmp_dir/$lang/$format/*", "$path/." )
-                            if ( -d "$tmp_dir/$lang/$format" );
+## TODO BUGBUG BZ #648126
+# for some reason the UTF8 file name is getting munged dep inside rcopy
+# works fron from the command line though O_O
+# perl -e 'use File::Copy::Recursive qw(rcopy);rcopy("build/en-US/html", "test");'
+#
+## Work around BZ #648126 ... gonna need to do an UTF8 audit maybe ...
+##  Check, UTF8 file names, UTF8 output from XmlClean, Translate, WebSite.
+##                        rcopy( "$tmp_dir/$lang/$format/*", "$path/." )
+                        system(
+                            qq|perl -e 'use File::Copy::Recursive qw(rcopy);rcopy( "$tmp_dir/$lang/$format/*", "$path/." )'|
+                        ) if ( -d "$tmp_dir/$lang/$format" );
                     }
                 }
             }
@@ -507,6 +519,14 @@ sub del_unwanted_xml {
 
 Ensure the XML validates against the DTD.
 
+To debug the XML catalogs
+
+export XML_DEBUG_CATALOG=1
+
+test...
+
+unset XML_DEBUG_CATALOG
+
 =cut
 
 sub validate_xml {
@@ -586,6 +606,13 @@ sub validate_xml {
     my $dtd_path
         = qq|http://www.oasis-open.org/docbook/xml/$dtdver/docbookx.dtd|;
 
+    if ( $dtdver >= 5 ) {
+        $dtd_type = qq|-//OASIS//DTD DocBook XML $dtdver//EN|;
+        $dtd_path
+            = qq|http://docbook.org/docbook/xml/$dtdver/dtd/docbook.dtd|;
+
+    }
+
     if ( 0 && $TEST_MML ) {
         $dtd_type = '-//OASIS//DTD DocBook MathML Module V1.0//EN';
         $dtd_path
@@ -1586,7 +1613,7 @@ sub package_home {
     mkpath("$tmp_dir/rpm");
 
     my $langs     = get_all_langs();
-    my @file_list = ('publican.cfg');
+    my @file_list = qw(publican.cfg site_overrides.css);
 
     foreach my $file (@file_list) {
         rcopy( $file, "$tmp_dir/tar/$tardir/." ) if ( -f $file );
@@ -1629,6 +1656,7 @@ sub package_home {
         'log'        => $log,
         tmpdir       => $tmp_dir,
         web_type     => $web_type,
+        spec_version => $Publican::SPEC_VERSION,
     );
 
     logger(
@@ -1766,15 +1794,28 @@ sub package {
         )
     ) if ( $short_sighted and not $desktop );
 
-    my $tmp_dir    = $self->{publican}->param('tmp_dir');
-    my $product    = $self->{publican}->param('product');
-    my $version    = $self->{publican}->param('version');
-    my $docname    = $self->{publican}->param('docname');
-    my $edition    = $self->{publican}->param('edition');
-    my $configfile = $self->{publican}->param('configfile');
-    my $release    = $self->{publican}->param('release');
-    my $xml_lang   = $self->{publican}->param('xml_lang');
-    my $type       = $self->{publican}->param('type');
+    my $tmp_dir           = $self->{publican}->param('tmp_dir');
+    my $product           = $self->{publican}->param('product');
+    my $version           = $self->{publican}->param('version');
+    my $docname           = $self->{publican}->param('docname');
+    my $edition           = $self->{publican}->param('edition');
+    my $configfile        = $self->{publican}->param('configfile');
+    my $release           = $self->{publican}->param('release');
+    my $xml_lang          = $self->{publican}->param('xml_lang');
+    my $type              = $self->{publican}->param('type');
+    my $web_formats_comma = $self->{publican}->param('web_formats');
+    my $web_formats       = $web_formats_comma;
+
+    $web_formats =~ s/,/ /g;
+
+    # No PDF for Indic packages. BZ #655713
+    if (   $lang =~ /(?:IN|ar-SA|fa-IR|he-IL)/
+        || $xml_lang =~ /(?:IN|ar-SA|fa-IR|he-IL)/ )
+    {
+        $web_formats_comma =~ s/pdf,//g;
+        $web_formats_comma =~ s/,pdf//g;
+        $web_formats       =~ s/\s*pdf\s*/ /g;
+    }
 
     if ( $lang ne $xml_lang ) {
         $release = undef;
@@ -1881,6 +1922,7 @@ sub package {
     my $doc_url           = $self->{publican}->param('doc_url');
     my $src_url           = $self->{publican}->param('src_url');
     my $dt_obsoletes      = $self->{publican}->param('dt_obsoletes') || "";
+    my $dt_requires       = $self->{publican}->param('dt_requires') || "";
     my $web_obsoletes     = $self->{publican}->param('web_obsoletes') || "";
     my $os_ver            = $self->{publican}->param('os_ver');
     my $translation       = ( $lang ne $xml_lang );
@@ -1891,6 +1933,10 @@ sub package {
         || "";
     my $web_name_label = $self->{publican}->param('web_name_label') || "";
 
+    my $menu_category = $self->{publican}->param('menu_category')
+        || "X-Red-Hat-Base;";
+    $menu_category .= ';' if ( $menu_category !~ /;\s*$/ );
+
     if ( $lang ne $xml_lang ) {
         my $xml_file = "$tmp_dir/$lang/xml/$type" . '_Info.xml';
         croak( maketext( "Can't locate required file: [_1]", $xml_file ) )
@@ -1923,7 +1969,7 @@ sub package {
     }
 
     $web_product_label =~ s/'/\\'/g;
-    $web_name_label =~ s/'/\\'/g;
+    $web_name_label    =~ s/'/\\'/g;
     $web_version_label =~ s/'/\\'/g;
 
     my $log = $self->change_log();
@@ -1943,30 +1989,35 @@ sub package {
     chomp($full_subtitle);
 
     my %xslt_opts = (
-        'book-title'  => $name_start,
-        'lang'        => $lang,
-        'prod'        => $product,
-        'prodver'     => $version,
-        'rpmver'      => $edition,
-        'rpmrel'      => $release,
-        'docname'     => $docname,
-        'license'     => $license,
-        'brand'       => "publican-$brand",
-        'url'         => $doc_url,
-        'src_url'     => $src_url,
-        'log'         => $log,
-        dt_obsoletes  => $dt_obsoletes,
-        web_obsoletes => $web_obsoletes,
-        translation   => $translation,
-        language      => $language,
-        abstract      => $abstract,
-        tmpdir        => $tmp_dir,
-        ICONS         => ( -e "$xml_lang/icons" ? 1 : 0 ),
-        product_label => $web_product_label,
-        version_label => $web_version_label,
-        name_label    => $web_name_label,
-        full_abstract => $full_abstract,
-        full_subtitle => $full_subtitle,
+        'book-title'      => $name_start,
+        lang              => $lang,
+        prod              => $product,
+        prodver           => $version,
+        rpmver            => $edition,
+        rpmrel            => $release,
+        docname           => $docname,
+        license           => $license,
+        brand             => "publican-$brand",
+        url               => $doc_url,
+        src_url           => $src_url,
+        'log'             => $log,
+        dt_obsoletes      => $dt_obsoletes,
+        dt_requires       => $dt_requires,
+        web_obsoletes     => $web_obsoletes,
+        translation       => $translation,
+        language          => $language,
+        abstract          => $abstract,
+        tmpdir            => $tmp_dir,
+        ICONS             => ( -e "$xml_lang/icons" ? 1 : 0 ),
+        product_label     => $web_product_label,
+        version_label     => $web_version_label,
+        name_label        => $web_name_label,
+        full_abstract     => $full_abstract,
+        full_subtitle     => $full_subtitle,
+        web_formats       => $web_formats,
+        web_formats_comma => $web_formats_comma,
+        menu_category     => $menu_category,
+        spec_version      => $Publican::SPEC_VERSION,
     );
 
     logger(
@@ -2267,6 +2318,11 @@ sub dtd_string {
     my $uri = qq|http://www.oasis-open.org/docbook/xml/$dtdver/docbookx.dtd|;
     my $dtd_type = qq|-//OASIS//DTD DocBook XML V$dtdver//EN|;
 
+    if ( $dtdver >= 5 ) {
+        $dtd_type = qq|-//OASIS//DTD DocBook XML $dtdver//EN|;
+        $uri = qq|http://docbook.org/docbook/xml/$dtdver/dtd/docbook.dtd|;
+    }
+
     if ( 0 && $TEST_MML ) {
         $dtd_type = '-//OASIS//DTD DocBook MathML Module V1.0//EN';
         $uri
@@ -2300,6 +2356,18 @@ sub dtd_string {
 <!DOCTYPE $tag PUBLIC "$dtd_type" "$uri" [
 DTDHEAD
 
+    # Include some DocBook 4 entities to reduce migration issues
+    if ( $dtdver >= 5 ) {
+        $dtd .= <<DB5;
+<!-- import a bunch of DocBook 4 entities -->
+<!ENTITY % sgml.features "IGNORE">
+<!ENTITY % xml.features "INCLUDE">
+<!ENTITY euro "&#8364;">
+<!ENTITY % dbcent PUBLIC "-//OASIS//ENTITIES DocBook Character Entities V4.4//EN" "http://www.oasis-open.org/docbook/xml/4.4/dbcentx.mod">
+%dbcent;
+DB5
+    }
+
     if ($TEST_MML) {
         $dtd .= <<MML;
 <!ENTITY % MATHML.prefixed "INCLUDE">
