@@ -2,6 +2,7 @@ package Publican::CreateBook;
 
 use strict;
 use warnings;
+use 5.008;
 use Carp;
 use Config::Simple;
 use XML::TreeBuilder;
@@ -15,6 +16,28 @@ use vars qw( $VERSION );
 
 $VERSION = '0.2';
 
+# Icon used for menu
+my $icon = q{<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<svg xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" version="1.0" width="32" height="32" id="svg3017">
+  <defs id="defs3019">
+    <linearGradient id="linearGradient2381">
+      <stop id="stop2383" style="stop-color:#ffffff;stop-opacity:1" offset="0"/>
+      <stop id="stop2385" style="stop-color:#ffffff;stop-opacity:0" offset="1"/>
+    </linearGradient>
+    <linearGradient x1="296.4996" y1="188.81061" x2="317.32471" y2="209.69398" id="linearGradient2371" xlink:href="#linearGradient2381" gradientUnits="userSpaceOnUse" gradientTransform="matrix(0.90776,0,0,0.90776,24.35648,49.24131)"/>
+  </defs>
+  <g transform="matrix(0.437808,-0.437808,0.437808,0.437808,-220.8237,43.55311)" id="g5089">
+    <path d="m 8.4382985,-6.28125 c -0.6073916,0 -4.3132985,5.94886271 -4.3132985,8.25 l 0,26.71875 c 0,0.846384 0.5818159,1.125 1.15625,1.125 l 25.5625,0 c 0.632342,0 1.125001,-0.492658 1.125,-1.125 l 0,-5.21875 0.28125,0 c 0.49684,0 0.906249,-0.409411 0.90625,-0.90625 l 0,-27.9375 c 0,-0.4968398 -0.40941,-0.90625 -0.90625,-0.90625 l -23.8117015,0 z" transform="translate(282.8327,227.1903)" id="path5091" style="fill:#5c5c4f;stroke:#000000;stroke-width:3.23021388;stroke-miterlimit:4;stroke-dasharray:none"/>
+    <rect width="27.85074" height="29.369793" rx="1.1414107" ry="1.1414107" x="286.96509" y="227.63805" id="rect5093" style="fill:#032c87"/>
+    <path d="m 288.43262,225.43675 25.2418,0 0,29.3698 -26.37615,0.0241 1.13435,-29.39394 z" id="rect5095" style="fill:#ffffff"/>
+    <path d="m 302.44536,251.73726 c 1.38691,7.85917 -0.69311,11.28365 -0.69311,11.28365 2.24384,-1.60762 3.96426,-3.47694 4.90522,-5.736 0.96708,2.19264 1.83294,4.42866 4.27443,5.98941 0,0 -1.59504,-7.2004 -1.71143,-11.53706 l -6.77511,0 z" id="path5097" style="fill:#a70000;fill-opacity:1;stroke-width:2"/>
+    <rect width="25.241802" height="29.736675" rx="0.89682275" ry="0.89682275" x="290.73544" y="220.92249" id="rect5099" style="fill:#809cc9"/>
+    <path d="m 576.47347,725.93939 6.37084,0.41502 0.4069,29.51809 c -1.89202,-1.31785 -6.85427,-3.7608 -8.26232,-1.68101 l 0,-26.76752 c 0,-0.82246 0.66212,-1.48458 1.48458,-1.48458 z" transform="matrix(0.499065,-0.866565,0,1,0,0)" id="rect5101" style="fill:#4573b3;fill-opacity:1"/>
+    <path d="m 293.2599,221.89363 20.73918,0 c 0.45101,0 0.8141,0.3631 0.8141,0.81411 0.21547,6.32836 -19.36824,21.7635 -22.36739,17.59717 l 0,-17.59717 c 0,-0.45101 0.3631,-0.81411 0.81411,-0.81411 z" id="path5103" style="opacity:0.65536726;fill:url(#linearGradient2371);fill-opacity:1"/>
+  </g>
+</svg>
+};
+
 =head1 NAME
 
 Publican::CreateBook - A module for generating documentation boilerplate
@@ -257,7 +280,7 @@ sub create {
                     [   'simpara',
                         [   'revhistory',
                             [   'revision',
-                                [ 'revnumber', '0' ],
+                                [ 'revnumber', '0-0' ],
                                 [   'date',
                                     DateTime->today()->strftime("%a %b %e %Y")
                                 ],
@@ -376,7 +399,8 @@ sub create {
     my $year = DateTime->today()->year();
 
     my $OUTDOC;
-    open( $OUTDOC, ">:utf8", "$name/$lang/$name" . ".ent" );
+    open( $OUTDOC, ">:utf8", "$name/$lang/$name" . ".ent" )
+        || croak( maketext( "Could not open entity file. [_1]", $@ ) );
     print $OUTDOC <<EOL;
 <!ENTITY PRODUCT "$product">
 <!ENTITY BOOKID "$name">
@@ -386,6 +410,11 @@ EOL
 
     close($OUTDOC);
 
+    open( $OUTDOC, ">:utf8", "$name/$lang/images/icon.svg" )
+        || croak( maketext( "Could not open icon file. [_1]", $@ ) );
+    print( $OUTDOC $icon );
+    close($OUTDOC);
+
     return;
 }
 
